==> workplayerapi-1.0.17.tgz: package/routes/login.js <==
/*
 * [EN]
 * Copyright (C) Kyros Technologies, Inc - All Rights Reserved
 *
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [NR]
 * Copyright (C) Kyros Technologies, Inc - Alle rettigheter reservert
 *
 * Uautorisert kopiering av denne filen, via hvilket som helst medium, er strengt forbudt
 * Egen og konfidensiell
 * Skrevet av Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [PT-BR]
 * Copyright (C) Kyros Technologies, Inc - Todos os direitos reservados
 *
 * Cópias não autorizadas deste arquivo, através de qualquer meio é estritamente proibido
 * Confidenciais e proprietários
 * Escrito por Kim Ruan <kimr@kyros.com.br>, Abril 2018
 */

import b64 from 'base-64';
import _ from 'lodash';

import unlogged from '../config/unlogged';

export const login = ({ email, password }) => {
    let body = {
        'email'    : email,
        'password' : b64.encode(password),
        'type'     : 'MOBILE'
    };

    let response = unlogged.post('/login', body)
        .then(res => {
            let headers = res.headers;
            let data    = res.data;
            let message = data.message;
            let error   = {
                data    : data,
                message : message
            };

            if (_.has(headers, 'x-token')) {
                console.log(res);
                return res;
            }
            else {
                console.log(error);
                return error;
            }
        })
        .catch(error => {
            let response = error.response;
            let request = error.request;
            let message = error.message;
            let config = error.config;

            if (response) {
                let data = response.data;
                let status = response.status;
                let headers = response.headers;
                let error = {
                    error: error,
                    message: message
                };

                console.log(data);
                console.log(status);
                console.log(headers);
                return error;
            }
            else if (request) {
                console.log(request);
                return request;
            }
            else {
                let error = {
                    config  : config,
                    message : message
                };
                console.log('Error', message);
                console.log(config);
                return error;
            }
        });
    
    console.log(JSON.stringify(response));
    return response;
};

==> workplayerapi-1.0.23.tgz: package/routes/login.js <==
/*
 * [EN]
 * Copyright (C) Kyros Technologies, Inc - All Rights Reserved
 *
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [NR]
 * Copyright (C) Kyros Technologies, Inc - Alle rettigheter reservert
 *
 * Uautorisert kopiering av denne filen, via hvilket som helst medium, er strengt forbudt
 * Egen og konfidensiell
 * Skrevet av Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [PT-BR]
 * Copyright (C) Kyros Technologies, Inc - Todos os direitos reservados
 *
 * Cópias não autorizadas deste arquivo, através de qualquer meio é estritamente proibido
 * Confidenciais e proprietários
 * Escrito por Kim Ruan <kimr@kyros.com.br>, Abril 2018
 */

import b64 from 'base-64';
import _ from 'lodash';

import unlogged from '../config/unlogged';
import { setToken } from '../config/logged';
import { Player } from '../classes/Player';

export const makeLogin = ({ email, password }) => {
    let body = {
        'email'    : email,
        'password' : b64.encode(password),
        'type'     : 'MOBILE'
    };

    return unlogged.post('/login', body)
        .then(res => {
            let headers = res.headers;
            let data    = res.data;
            let message = data.message;

            if (_.has(headers, 'x-token')) {
                let player = new Player(data.object);
                let token  = _.get(headers, 'x-token');
                setToken(token);
                return {
                    result : 'LOGIN_SUCCESS',
                    data   : {
                        token  : token,
                        player : player
                    }
                };
            }
            else {
                return {
                    result : 'LOGIN_FAIL',
                    data   : message
                };
            }
        })
        .catch(error => {
            let response = error.response;
            let request  = error.request;
            let message  = error.message;
            let config   = error.config;

            if (response) {
                let data    = response.data;
                let status  = response.status;
                let headers = response.headers;

                console.log(data);
                console.log(status);
                console.log(headers);
                return {
                    result : 'LOGIN_FAIL',
                    data   : message
                };
            }
            else if (request) {
                console.log(request);
                return {
                    result : 'LOGIN_FAIL',
                    data   : message
                };
            }
            else {
                console.log('Error', message);
                console.log(config);
                return {
                    result : 'LOGIN_FAIL',
                    data   : message
                };
            }
        });
};

module.exports = {
    makeLogin
};
